const debug=require('debug')('debug');

//start
debug('api start...');

require('dotenv').config();
const HELMET = require('helmet');
const COMPRESSION = require('compression');

const EXPRESS = require("express");
const CORS = require("cors");

const ROOTROUTER = require('./route/root');

const STOPS_GTFS_DE_ROUTER = require('./route/gtfs-stops-de');
const STOPS_GTFS_DE_NO_GI_ROUTER = require('./route/gtfs-stops-de-not-dhid');
const STOPS_GTFS_DE_NO_GI_REFINE_ROUTER = require('./route/gtfs-stops-de-not-dhid-refine');

const STOP_NAME_COUNT_NO_GI_ROUTER = require('./route/stop-names-count-no-gi');
const STOP_NAME_COUNT_PART_GI_ROUTER = require('./route/stop-names-count-part-gi');

const STOP_NAME_NO_GI_ROUTER = require('./route/stop-names-no-gi');
const STOP_NAME_PART_GI_ROUTER = require('./route/stop-names-part-gi');

const STOPS_COUNT_GTFS_LT_0 = require('./route/stops-count-gtfs-lt-0');

const STOPS_COUNT_GTFS = require('./route/stops-count-gtfs');

const STOPS_COUNT_GTFS_DE = require('./route/stops-count-gtfs-de');

const STOPS_COUNT_GTFS_DE_NO_GI = require('./route/stops-count-gtfs-de-not-dhid');

const STOPS_COUNT_GTFS_DE_HB = require('./route/stops-count-gtfs-de-hb');
const STOPS_COUNT_GTFS_DE_HH = require('./route/stops-count-gtfs-de-hh');
const STOPS_COUNT_GTFS_DE_NI = require('./route/stops-count-gtfs-de-ni');
const STOPS_COUNT_GTFS_DE_SH = require('./route/stops-count-gtfs-de-sh');
const STOPS_COUNT_GTFS_DE_MV = require('./route/stops-count-gtfs-de-mv');
const STOPS_COUNT_GTFS_DE_BB = require('./route/stops-count-gtfs-de-bb');
const STOPS_COUNT_GTFS_DE_BE = require('./route/stops-count-gtfs-de-be');
const STOPS_COUNT_GTFS_DE_ST = require('./route/stops-count-gtfs-de-st');
const STOPS_COUNT_GTFS_DE_NW = require('./route/stops-count-gtfs-de-nw');
const STOPS_COUNT_GTFS_DE_HE = require('./route/stops-count-gtfs-de-he');
const STOPS_COUNT_GTFS_DE_SN = require('./route/stops-count-gtfs-de-sn');
const STOPS_COUNT_GTFS_DE_TH = require('./route/stops-count-gtfs-de-th');
const STOPS_COUNT_GTFS_DE_RP = require('./route/stops-count-gtfs-de-rp');
const STOPS_COUNT_GTFS_DE_SL = require('./route/stops-count-gtfs-de-sl');
const STOPS_COUNT_GTFS_DE_BY = require('./route/stops-count-gtfs-de-by');
const STOPS_COUNT_GTFS_DE_BW = require('./route/stops-count-gtfs-de-bw');

const STOPS_COUNT_GTFS_DE_HB_NO_GI = require('./route/stops-count-gtfs-de-hb-not-dhid');
const STOPS_COUNT_GTFS_DE_HH_NO_GI = require('./route/stops-count-gtfs-de-hh-not-dhid');
const STOPS_COUNT_GTFS_DE_NI_NO_GI = require('./route/stops-count-gtfs-de-ni-not-dhid');
const STOPS_COUNT_GTFS_DE_SH_NO_GI = require('./route/stops-count-gtfs-de-sh-not-dhid');
const STOPS_COUNT_GTFS_DE_MV_NO_GI = require('./route/stops-count-gtfs-de-mv-not-dhid');
const STOPS_COUNT_GTFS_DE_BB_NO_GI = require('./route/stops-count-gtfs-de-bb-not-dhid');
const STOPS_COUNT_GTFS_DE_BE_NO_GI = require('./route/stops-count-gtfs-de-be-not-dhid');
const STOPS_COUNT_GTFS_DE_ST_NO_GI = require('./route/stops-count-gtfs-de-st-not-dhid');
const STOPS_COUNT_GTFS_DE_NW_NO_GI = require('./route/stops-count-gtfs-de-nw-not-dhid');
const STOPS_COUNT_GTFS_DE_HE_NO_GI = require('./route/stops-count-gtfs-de-he-not-dhid');
const STOPS_COUNT_GTFS_DE_SN_NO_GI = require('./route/stops-count-gtfs-de-sn-not-dhid');
const STOPS_COUNT_GTFS_DE_TH_NO_GI = require('./route/stops-count-gtfs-de-th-not-dhid');
const STOPS_COUNT_GTFS_DE_RP_NO_GI = require('./route/stops-count-gtfs-de-rp-not-dhid');
const STOPS_COUNT_GTFS_DE_SL_NO_GI = require('./route/stops-count-gtfs-de-sl-not-dhid');
const STOPS_COUNT_GTFS_DE_BY_NO_GI = require('./route/stops-count-gtfs-de-by-not-dhid');
const STOPS_COUNT_GTFS_DE_BW_NO_GI = require('./route/stops-count-gtfs-de-bw-not-dhid');

const GTFS_STOPS_LAST_VACUUM = require('./route/gtfs-stops-last-vacuum');

const STOPS_COUNT_ZHV = require('./route/stops-count-zhv');

//TODO make this list available via config
//limit access to this origin list
let whitelist = [
    'http(s)://foo.bar'
];

const APP = EXPRESS();

//compress all routes
APP.use(COMPRESSION());

//protect against vulnerabilities
APP.use(HELMET());

//configure CORS
APP.use(CORS({
    origin: function(origin, callback){
        // allow requests with no origin
        debug('origin: '+origin)
        if(!origin){
            return callback(null, true);
        }
        if(whitelist.indexOf(origin) === -1){
            let message = 'The CORS policy for this origin does not allow access from the particular origin: '+origin;
            return callback(new Error(message), false);
        }
        debug('origin: '+origin+' allowed by CORS');
        return callback(null, true);
    }
}));

//api enable/disable?
APP.use('/', ROOTROUTER);
APP.use('/gtfs-stops-de',STOPS_GTFS_DE_ROUTER);
APP.use('/gtfs-stops-de-not-dhid',STOPS_GTFS_DE_NO_GI_ROUTER);
APP.use('/gtfs-stops-de-not-dhid-refine',STOPS_GTFS_DE_NO_GI_REFINE_ROUTER);

APP.use('/stops-count-gtfs-lt-0',STOPS_COUNT_GTFS_LT_0);

APP.use('/stops-count-gtfs',STOPS_COUNT_GTFS);

APP.use('/stops-count-gtfs-de',STOPS_COUNT_GTFS_DE);
APP.use('/stops-count-gtfs-de-not-dhid',STOPS_COUNT_GTFS_DE_NO_GI);

APP.use('/stop-names-count-no-gi',STOP_NAME_COUNT_NO_GI_ROUTER);
APP.use('/stop-names-count-part-gi',STOP_NAME_COUNT_PART_GI_ROUTER);

APP.use('/stop-names-no-gi',STOP_NAME_NO_GI_ROUTER);
APP.use('/stop-names-part-gi',STOP_NAME_PART_GI_ROUTER);

APP.use('/stops-count-gtfs-de-hb',STOPS_COUNT_GTFS_DE_HB);
APP.use('/stops-count-gtfs-de-hh',STOPS_COUNT_GTFS_DE_HH);
APP.use('/stops-count-gtfs-de-ni',STOPS_COUNT_GTFS_DE_NI);
APP.use('/stops-count-gtfs-de-sh',STOPS_COUNT_GTFS_DE_SH);
APP.use('/stops-count-gtfs-de-mv',STOPS_COUNT_GTFS_DE_MV);
APP.use('/stops-count-gtfs-de-bb',STOPS_COUNT_GTFS_DE_BB);
APP.use('/stops-count-gtfs-de-be',STOPS_COUNT_GTFS_DE_BE);
APP.use('/stops-count-gtfs-de-st',STOPS_COUNT_GTFS_DE_ST);
APP.use('/stops-count-gtfs-de-nw',STOPS_COUNT_GTFS_DE_NW);
APP.use('/stops-count-gtfs-de-he',STOPS_COUNT_GTFS_DE_HE);
APP.use('/stops-count-gtfs-de-sn',STOPS_COUNT_GTFS_DE_SN);
APP.use('/stops-count-gtfs-de-th',STOPS_COUNT_GTFS_DE_TH);
APP.use('/stops-count-gtfs-de-rp',STOPS_COUNT_GTFS_DE_RP);
APP.use('/stops-count-gtfs-de-sl',STOPS_COUNT_GTFS_DE_SL);
APP.use('/stops-count-gtfs-de-by',STOPS_COUNT_GTFS_DE_BY);
APP.use('/stops-count-gtfs-de-bw',STOPS_COUNT_GTFS_DE_BW);

APP.use('/stops-count-gtfs-de-hb-not-dhid',STOPS_COUNT_GTFS_DE_HB_NO_GI);
APP.use('/stops-count-gtfs-de-hh-not-dhid',STOPS_COUNT_GTFS_DE_HH_NO_GI);
APP.use('/stops-count-gtfs-de-ni-not-dhid',STOPS_COUNT_GTFS_DE_NI_NO_GI);
APP.use('/stops-count-gtfs-de-sh-not-dhid',STOPS_COUNT_GTFS_DE_SH_NO_GI);
APP.use('/stops-count-gtfs-de-mv-not-dhid',STOPS_COUNT_GTFS_DE_MV_NO_GI);
APP.use('/stops-count-gtfs-de-bb-not-dhid',STOPS_COUNT_GTFS_DE_BB_NO_GI);
APP.use('/stops-count-gtfs-de-be-not-dhid',STOPS_COUNT_GTFS_DE_BE_NO_GI);
APP.use('/stops-count-gtfs-de-st-not-dhid',STOPS_COUNT_GTFS_DE_ST_NO_GI);
APP.use('/stops-count-gtfs-de-nw-not-dhid',STOPS_COUNT_GTFS_DE_NW_NO_GI);
APP.use('/stops-count-gtfs-de-he-not-dhid',STOPS_COUNT_GTFS_DE_HE_NO_GI);
APP.use('/stops-count-gtfs-de-sn-not-dhid',STOPS_COUNT_GTFS_DE_SN_NO_GI);
APP.use('/stops-count-gtfs-de-th-not-dhid',STOPS_COUNT_GTFS_DE_TH_NO_GI);
APP.use('/stops-count-gtfs-de-rp-not-dhid',STOPS_COUNT_GTFS_DE_RP_NO_GI);
APP.use('/stops-count-gtfs-de-sl-not-dhid',STOPS_COUNT_GTFS_DE_SL_NO_GI);
APP.use('/stops-count-gtfs-de-by-not-dhid',STOPS_COUNT_GTFS_DE_BY_NO_GI);
APP.use('/stops-count-gtfs-de-bw-not-dhid',STOPS_COUNT_GTFS_DE_BW_NO_GI);

APP.use('/gtfs-stops-last-vacuum',GTFS_STOPS_LAST_VACUUM);
APP.use('/stops-count-zhv',STOPS_COUNT_ZHV);

module.exports=APP;

//end
debug('api done..');















